#include <YMZ294.h>
#include <Wire.h>

#define ADDR_FREQ_A CH_A
#define ADDR_FREQ_B CH_B
#define ADDR_FREQ_C CH_C

//-- for I2C LCD
int sdaPin = 18; // analog pin 4
int sclPin = 19; // analog pin 5
int i2cadr = 0x3e;
byte contrast = 7; // 0-63 5V系だとかなり少なくする

// Output Pins
const byte WRCS_PIN = 8;
const byte A0_PIN = 9;
const byte RESET_PIN = 10;

YMZ294 ymz(WRCS_PIN, A0_PIN, RESET_PIN);

void lcd_cmd(byte x)
{
  Wire.beginTransmission(i2cadr);
  Wire.write(0x00);
  Wire.write(x);
  Wire.endTransmission();
}

void lcd_data(byte x)
{
  Wire.beginTransmission(i2cadr);
  Wire.write(0x40);
  Wire.write(x);
  Wire.endTransmission();
}

void lcd_puts(const char *s)
{
  while(*s) lcd_data(*s++);
}

void lcd_init()
{
  Wire.begin();
  lcd_cmd(0x38); // function set
  lcd_cmd(0x39); // function set
  lcd_cmd(0x14); // interval osc
  lcd_cmd(0x70 | (contrast & 15)); // contrast low
  lcd_cmd(0x5c | (contrast >> 4 & 3)); // contrast high / icon / power
  lcd_cmd(0x6c); // follower control
  delay(300);
  lcd_cmd(0x38); // function set
  lcd_cmd(0x0c); // display on
  lcd_cmd(0x01); // clear display
  delay(2);
}

void lcd_move(byte pos){
  lcd_cmd(0x80 | pos);
}

void set_ch(Channel ch, int note) {
  if(ch==CH_A || ch==CH_B) {
  ymz.SetEnvShape(1,0,0,1);
  ymz.SetEnvFrequency(15);
  }
  ymz.SetFrequency(ch, noteFreq[note]);
}

void user_delay(int time) {
  delay(time / 1.1);
}

void setup() {
    
  lcd_init();
  lcd_puts("GRADIUS MEDLEY");
  lcd_move(0x40);
  lcd_puts("#2 STONEHENGE");
  
  DDRD = 0b11111111;
  pinMode(WRCS_PIN, OUTPUT);
  pinMode(A0_PIN, OUTPUT);
  pinMode(RESET_PIN, OUTPUT);

  ymz.Reset();

  ymz.SetMixer(0b111, 0b000);

  ymz.SetVolume(CH_A, 0b00001111);
  ymz.SetFreqBit(CH_A, 0);
  ymz.SetVolume(CH_B, 0b00001111);
  ymz.SetFreqBit(CH_B, 0);
  ymz.SetVolume(CH_C, 0b00001111);
  ymz.SetFreqBit(CH_C, 0);

  ymz.SetEnvEnable(CH_A, true);
  ymz.SetEnvEnable(CH_B, true);
  ymz.SetEnvEnable(CH_C, false);

}

void loop() {
  playSong();
}

void playStart() {
}

void playSong() {
  
 
  set_ch(ADDR_FREQ_C,38);
  user_delay(164);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(98);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(106);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(214);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,38);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(107);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(106);
  set_ch(ADDR_FREQ_A,71);
  set_ch(ADDR_FREQ_B,67);
  user_delay(8);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(89);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,50);
  user_delay(8);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(204);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(106);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,53);
  user_delay(98);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(89);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,53);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(106);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,71);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,68);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,50);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,76);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,72);
  set_ch(ADDR_FREQ_C,50);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,50);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,75);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,49);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,49);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,74);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,70);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,48);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,48);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,75);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,49);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,49);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,76);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,72);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,50);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,77);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,73);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,51);
  user_delay(214);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,40);
  user_delay(213);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(214);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,40);
  user_delay(204);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(107);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,77);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,73);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,51);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,40);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,40);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,77);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,77);
  set_ch(ADDR_FREQ_C,43);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  user_delay(98);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,40);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,40);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,40);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,40);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,78);
  set_ch(ADDR_FREQ_B,74);
  set_ch(ADDR_FREQ_C,40);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,77);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,77);
  set_ch(ADDR_FREQ_C,43);
  user_delay(98);
  set_ch(ADDR_FREQ_C,0);
  user_delay(7);

  ymz.SetEnvEnable(CH_A, false);
  ymz.SetEnvEnable(CH_B, false);

  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,82);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,78);
  set_ch(ADDR_FREQ_C,44);
  user_delay(53);
  set_ch(ADDR_FREQ_C,0);
  user_delay(44);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,44);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,51);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,54);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,58);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,60);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,63);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,66);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,63);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,60);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,58);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,54);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,51);
  user_delay(88);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,82);
  set_ch(ADDR_FREQ_B,78);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,44);
  user_delay(72);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,51);
  user_delay(17);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(16);
  set_ch(ADDR_FREQ_A,82);
  set_ch(ADDR_FREQ_B,78);
  user_delay(35);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,54);
  user_delay(71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,58);
  user_delay(71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,60);
  user_delay(35);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,77);
  user_delay(34);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,62);
  user_delay(71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,53);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,57);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,59);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,62);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,65);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,62);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,59);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,57);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,53);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(89);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,77);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(70);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(17);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,81);
  set_ch(ADDR_FREQ_B,77);
  user_delay(34);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,53);
  user_delay(71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,57);
  user_delay(70);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,59);
  user_delay(35);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,80);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,76);
  user_delay(35);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,62);
  user_delay(71);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,42);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,49);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,56);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,58);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,61);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,64);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,61);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,58);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,56);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,52);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,49);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,77);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,73);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,39);
  user_delay(88);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,77);
  set_ch(ADDR_FREQ_B,73);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,46);
  user_delay(107);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,49);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(98);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,38);
  user_delay(212);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(99);
  set_ch(ADDR_FREQ_C,0);
  user_delay(7);
  set_ch(ADDR_FREQ_C,38);
  user_delay(117);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(88);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  
  ymz.SetEnvEnable(CH_A, true);
  ymz.SetEnvEnable(CH_B, true);
  
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,57);
  set_ch(ADDR_FREQ_C,38);
  user_delay(52);
  set_ch(ADDR_FREQ_C,0);
  user_delay(142);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,57);
  set_ch(ADDR_FREQ_C,38);
  user_delay(88);
  set_ch(ADDR_FREQ_A,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,63);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,60);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,41);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(7);
  set_ch(ADDR_FREQ_A,63);
  set_ch(ADDR_FREQ_B,60);
  set_ch(ADDR_FREQ_C,41);
  user_delay(214);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,72);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,69);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(205);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,38);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(214);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(97);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,38);
  user_delay(115);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(88);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,57);
  set_ch(ADDR_FREQ_C,38);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,57);
  set_ch(ADDR_FREQ_C,38);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,44);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,44);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);
  user_delay(106);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,44);
  user_delay(88);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(9);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,44);
  user_delay(196);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(8);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,44);
  user_delay(213);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,65);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,62);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,44);
  user_delay(508);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,66);
  set_ch(ADDR_FREQ_B,63);
  set_ch(ADDR_FREQ_C,44);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,65);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,62);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,43);
  user_delay(106);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,63);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,60);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,41);
  user_delay(88);
  set_ch(ADDR_FREQ_B,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,60);
  set_ch(ADDR_FREQ_B,57);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,38);
  user_delay(321);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,45);
  user_delay(106);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,48);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,48);
  user_delay(214);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,50);
  user_delay(213);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,48);
  user_delay(88);
  set_ch(ADDR_FREQ_A,0);
  user_delay(17);
  set_ch(ADDR_FREQ_A,63);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,60);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,53);
  user_delay(195);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  user_delay(9);
  set_ch(ADDR_FREQ_C,0);
  user_delay(8);
  set_ch(ADDR_FREQ_A,63);
  set_ch(ADDR_FREQ_B,60);
  set_ch(ADDR_FREQ_C,53);
  user_delay(214);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);

}


