#include <YMZ294.h>
#include <Wire.h>

#define ADDR_FREQ_A CH_A
#define ADDR_FREQ_B CH_B
#define ADDR_FREQ_C CH_C

//-- for I2C LCD
int sdaPin = 18; // analog pin 4
int sclPin = 19; // analog pin 5
int i2cadr = 0x3e;
byte contrast = 7; // 0-63 5V系だとかなり少なくする

// Output Pins
const byte WRCS_PIN = 8;
const byte A0_PIN = 9;
const byte RESET_PIN = 10;

YMZ294 ymz(WRCS_PIN, A0_PIN, RESET_PIN);

void lcd_cmd(byte x)
{
  Wire.beginTransmission(i2cadr);
  Wire.write(0x00);
  Wire.write(x);
  Wire.endTransmission();
}

void lcd_data(byte x)
{
  Wire.beginTransmission(i2cadr);
  Wire.write(0x40);
  Wire.write(x);
  Wire.endTransmission();
}

void lcd_puts(const char *s)
{
  while(*s) lcd_data(*s++);
}

void lcd_init()
{
  Wire.begin();
  lcd_cmd(0x38); // function set
  lcd_cmd(0x39); // function set
  lcd_cmd(0x14); // interval osc
  lcd_cmd(0x70 | (contrast & 15)); // contrast low
  lcd_cmd(0x5c | (contrast >> 4 & 3)); // contrast high / icon / power
  lcd_cmd(0x6c); // follower control
  delay(300);
  lcd_cmd(0x38); // function set
  lcd_cmd(0x0c); // display on
  lcd_cmd(0x01); // clear display
  delay(2);
}

void lcd_move(byte pos){
  lcd_cmd(0x80 | pos);
}

void set_ch(Channel ch, int note) {
  if(ch==CH_A || ch==CH_B) {
    ymz.SetEnvShape(1,0,0,1);
    ymz.SetEnvFrequency(10);
  }
  ymz.SetFrequency(ch, noteFreq[note]);
}

void user_delay(int time) {
  delay(time / 1.1);
}

/*
void set_ch(Channel ch, int note) {
 int input_delay = map(analogRead(A2),0,1023,0,11);
 ymz.SetFrequency(ch, noteFreq[note-input_delay]);
 }
 
 void user_delay(int time) {
 //float input_delay = (float)map(analogRead(A2),0,1023,70,700)/100.0;
 delay(time / 1.2);
 //delay(time / input_delay);
 }
 */

void setup() {
  lcd_init();
  lcd_puts("GRADIUS MEDLEY");
  lcd_move(0x40);
  lcd_puts("* * *START* * *");

  DDRD = 0b11111111;
  pinMode(WRCS_PIN, OUTPUT);
  pinMode(A0_PIN, OUTPUT);
  pinMode(RESET_PIN, OUTPUT);

  ymz.Reset();

  ymz.SetMixer(0b111, 0b000);

  ymz.SetVolume(CH_A, 0b00001110);
  ymz.SetFreqBit(CH_A, 0);
  ymz.SetVolume(CH_B, 0b00001110);
  ymz.SetFreqBit(CH_B, 0);
  ymz.SetVolume(CH_C, 0b00001111);
  ymz.SetFreqBit(CH_C, 0);

  ymz.SetEnvEnable(CH_A, false);
  ymz.SetEnvEnable(CH_B, false);
  ymz.SetEnvEnable(CH_C, false);

  playStart();
}

void loop() {
  ymz.Reset();
}

void playStart() {

  set_ch(ADDR_FREQ_A,71);
  set_ch(ADDR_FREQ_B,83);
  set_ch(ADDR_FREQ_C,62);
  user_delay(97);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,74);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,86);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,67);
  user_delay(124);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,79);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,91);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,71);
  user_delay(124);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,83);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,95);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,74);
  user_delay(124);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_A,79);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_B,91);
  set_ch(ADDR_FREQ_C,0);
  set_ch(ADDR_FREQ_C,71);
  user_delay(374);
  set_ch(ADDR_FREQ_A,0);
  set_ch(ADDR_FREQ_B,0);
  set_ch(ADDR_FREQ_C,0);


}

void playSong() {


}




